# Leonhard
A commons library for Project Euler problems.

## Installation
`pip install leonhard`

## Usage
```python
>>> from leonhard import leonhard
>>> print(leonhard.get_factors_of_positive_integer(10))
[1, 2, 5, 10]
```

## Functionalities
* `get_factors_of_positive_integer`: Gets the factors of a given positive integer
* `generate_fibonacci_sequence`: Generates a Fibonacci sequence


